@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001, The Free Software Foundation
+ * Copyright (C) 1999-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -25,9 +25,9 @@
 #endif
 
 #include <libgda/gda-config.h>
+#include <libgnomedb/gnome-db-data-source-selector.h>
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-util.h>
-#include <gtk/gtkcombo.h>
 #include <gtk/gtktable.h>
 
 #include "gnome-db-intl.h"
@@ -64,28 +64,6 @@ static GObjectClass *parent_class = NULL;
  * Private functions
  */
 
-static void
-load_data_sources (GtkCombo *combo)
-{
-	GList *dsn_list;
-	GList *l;
-	GList *strings = NULL;
-
-	g_return_if_fail (GTK_IS_COMBO (combo));
-
-	dsn_list = gda_config_get_data_source_list ();
-	for (l = dsn_list; l != NULL; l = l->next) {
-		GdaDataSourceInfo *dsn_info = (GdaDataSourceInfo *) l->data;
-		strings = g_list_append (strings, dsn_info->name);
-	}
-
-	gtk_combo_set_popdown_strings (combo, strings);
-
-	/* free memory */
-	g_list_free (strings);
-	gda_config_free_data_source_list (dsn_list);
-}
-
 /*
  * GnomeDbLogin class implementation
  */
@@ -223,16 +201,8 @@ gnome_db_login_construct (GnomeDbLogin *login, const gchar *dsn)
 
 	label = gnome_db_new_label_widget (_("Data Source"));
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 2, 2);
-	if (dsn != NULL) {
-		login->priv->dsn_entry = gnome_db_new_entry_widget (0, FALSE);
-		gtk_entry_set_text (GTK_ENTRY (login->priv->dsn_entry), dsn);
-		gtk_editable_set_editable (GTK_ENTRY (login->priv->dsn_entry), FALSE);
-	}
-	else {
-		login->priv->dsn_entry = gnome_db_new_combo_widget ();
-		gtk_combo_set_value_in_list (GTK_COMBO (login->priv->dsn_entry), TRUE, FALSE);
-		load_data_sources (GTK_COMBO (login->priv->dsn_entry));
-	}
+	login->priv->dsn_entry = gnome_db_data_source_selector_new (dsn);
+	gtk_widget_show (login->priv->dsn_entry);
 	gtk_table_attach (GTK_TABLE (table), login->priv->dsn_entry, 1, 2, 0, 1,
 			  GTK_FILL, GTK_FILL, 2, 2);
 
@@ -270,17 +240,12 @@ gnome_db_login_new (const gchar *dsn)
 const gchar *
 gnome_db_login_get_dsn (GnomeDbLogin *login)
 {
-	GtkEntry *entry;
-
 	g_return_val_if_fail (GNOME_DB_IS_LOGIN (login), NULL);
 
 	if (login->priv->dsn_name)
 		return (const gchar *) login->priv->dsn_name;
 
-	entry = GTK_ENTRY (GTK_COMBO (login->priv->dsn_entry)->entry);
-	g_return_val_if_fail (GTK_IS_ENTRY (entry), NULL);
-
-	return gtk_entry_get_text (entry);
+	return gnome_db_option_menu_get_selection (GTK_OPTION_MENU (login->priv->dsn_entry));
 }
 
 /**
