@@ -483,6 +483,34 @@ gnome_db_option_menu_get_selection (GtkOptionMenu *option_menu)
 	return NULL;
 }
 
+/**
+ * gnome_db_option_menu_set_selection
+ */
+void
+gnome_db_option_menu_set_selection (GtkOptionMenu *option_menu, const gchar *selection)
+{
+	GtkWidget *menu;
+	GList *l;
+
+	g_return_if_fail (GTK_IS_OPTION_MENU (option_menu));
+
+	menu = gtk_option_menu_get_menu (option_menu);
+	if (!GTK_IS_MENU_SHELL (menu))
+		return;
+
+	for (l = GTK_MENU_SHELL (menu)->children; l != NULL; l = l->next) {
+		const gchar *str;
+		GtkWidget *menu_item = GTK_WIDGET (l->data);
+
+		str = (const gchar *) g_object_get_data (G_OBJECT (menu_item),
+							 "GNOME:Database:MenuItemLabel");
+		if (str && !strcmp (str, selection)) {
+			gtk_menu_shell_activate_item (GTK_MENU_SHELL (menu), menu_item, TRUE);
+			break;
+		}
+	}
+}
+
 /**
  * gnome_db_text_clear
  * @text: a #GtkTextView widget
