@@ -62,6 +62,8 @@ void         gnome_db_set_widget_fg_color (GtkWidget *widget, const gchar *color
 
 void         gnome_db_option_menu_add_item (GtkOptionMenu *option_menu, const gchar *label);
 const gchar *gnome_db_option_menu_get_selection (GtkOptionMenu *option_menu);
+void         gnome_db_option_menu_set_selection (GtkOptionMenu *option_menu,
+						 const gchar *selection);
 
 void         gnome_db_text_clear (GtkTextView *text);
 void         gnome_db_text_copy_clipboard (GtkTextView *text);
