@@ -29,6 +29,7 @@
 #include <libgnomedb/gnome-db-connection-selector.h>
 #include <libgnomedb/gnome-db-control.h>
 #include <libgnomedb/gnome-db-control-widget.h>
+#include <libgnomedb/gnome-db-data-source-selector.h>
 #include <libgnomedb/gnome-db-dsn-config-druid.h>
 #include <libgnomedb/gnome-db-dsn-config.h>
 #include <libgnomedb/gnome-db-error.h>
@@ -39,6 +40,7 @@
 #include <libgnomedb/gnome-db-login.h>
 #include <libgnomedb/gnome-db-login-dialog.h>
 #include <libgnomedb/gnome-db-model.h>
+#include <libgnomedb/gnome-db-provider-selector.h>
 #include <libgnomedb/gnome-db-table-editor.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <libgnomedb/gnome-db-window.h>
